require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_nservice',
  dscmeta_resource_friendly_name: 'nService',
  dscmeta_resource_name: 'Nana_nService',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'nPSDesiredStateConfiguration',
  dscmeta_module_version: '1.1',
  docs: 'The DSC nService resource type.
         Automatically generated from version 1.1',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_startuptype: {
      type: "Optional[Enum['Automatic', 'Manual', 'Disabled']]",
      desc: 'StartupType to set for the service',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'Display name for the service, if not specified, Name is used',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the service',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Enum['Running', 'Stopped']",
      desc: 'State to set the service to',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
